@@ -3,8 +3,10 @@ Define context in which a plug-in runs
 """
 from __future__ import annotations
 
-from dataclasses import dataclass
+import logging
 import multiprocessing
+
+from dataclasses import dataclass
 from typing import TYPE_CHECKING, Any, Optional
 
 # Only import these classes during type-checking
@@ -37,3 +39,4 @@ class Context:  # pylint: disable="too-many-instance-attributes"
     retry_wait_seconds: float = 5
     logfile_lock: Optional[Any] = multiprocessing.Manager().RLock()
     logfile_location: str = "hoppr.log"
+    log_level: int = logging.INFO
