@@ -21,3 +21,6 @@ class PurlType(Enum):
     MAVEN = "maven"
     GENERIC = "generic"
     APT = "apt"
+
+    def __str__(self) -> str:
+        return self.value
