@@ -1,12 +1,14 @@
 """
 Framework for manipulating bundles for airgapped transfers.
 """
+import logging
 import sys
+
 from pathlib import Path
 from platform import python_version
-from typing import List
+from typing import List, Optional
 
-from typer import Argument, Option, Typer, echo  # pylint: disable=unused-import
+from typer import Argument, Option, Typer, echo
 
 from hoppr import __version__
 from hoppr.configs.credentials import Credentials
@@ -17,6 +19,22 @@ from hoppr.processor import HopprProcessor
 app = Typer()
 
 
+@app.callback()
+def verbose(
+    verbose_flag: Optional[bool] = Option(
+        False,
+        "-v",
+        "--debug",
+        "--verbose",
+        help="Enable debug output",
+    )
+):
+    """
+    Define, validate, and transfer dependencies between environments.
+    """
+    return verbose_flag
+
+
 @app.command()
 def bundle(
     manifest_file: Path = Argument(
@@ -45,6 +63,13 @@ def bundle(
         help="File to which log will be written",
         envvar="HOPPR_LOG_FILE",
     ),
+    verbose_flag: Optional[bool] = Option(
+        False,
+        "-v",
+        "--debug",
+        "--verbose",
+        help="Enable debug output",
+    ),
 ):
     """
     Run the stages specified in the transfer config file on the
@@ -58,19 +83,28 @@ def bundle(
         metadata_files.append(credentials_file)
 
     manifest = Manifest.load_file(manifest_file)
-
     transfer = Transfer.load_file(transfer_file)
+    log_level = logging.DEBUG if verbose_flag else logging.INFO
 
-    processor = HopprProcessor(transfer, manifest)
+    processor = HopprProcessor(transfer, manifest, log_level)
     processor.metadata_files = metadata_files
 
     result = processor.run(log_file)
+
     if result.is_fail():
         sys.exit(1)
 
 
 @app.command()
-def version():
+def version(
+    verbose_flag: Optional[bool] = Option(  # pylint: disable=unused-argument
+        False,
+        "-v",
+        "--debug",
+        "--verbose",
+        help="Enable debug output",
+    ),
+):
     """
     Print version information for `hoppr`
     """
@@ -81,18 +115,27 @@ def version():
 @app.command()
 def validate(
     input_files: List[Path],
-    credentials_config_file: Path = Option(
+    credentials_file: Path = Option(
         None,
         "-c",
         "--credentials",
-        help="Specify authorization config for services",
+        help="Specify credentials config for services",
         envvar="HOPPR_CREDS_CONFIG",
     ),
-    transfer_config_file: Path = Option(
-        None,
-        help="Specify transfer config for services",
+    transfer_file: Path = Option(
+        "transfer.yml",
+        "-t",
+        "--transfer",
+        help="Specify transfer config",
         envvar="HOPPR_TRANSFER_CONFIG",
     ),
+    verbose_flag: Optional[bool] = Option(  # pylint: disable=unused-argument
+        False,
+        "-v",
+        "--debug",
+        "--verbose",
+        help="Enable debug output",
+    ),
 ):
     """
     Validate multiple manifest files for schema errors.
@@ -102,10 +145,10 @@ def validate(
     transfer_config = None  # pylint: disable="unused-variable"
     manifests = []  # pylint: disable="unused-variable"
 
-    if credentials_config_file is not None:
-        cred_config = Credentials.load_file(credentials_config_file)
-    if transfer_config_file is not None:
-        transfer_config = Transfer.load_file(transfer_config_file)
+    if credentials_file is not None:
+        cred_config = Credentials.load_file(credentials_file)
+    if transfer_file is not None:
+        transfer_config = Transfer.load_file(transfer_file)
 
     manifests = [Manifest.load_file(file, cred_config) for file in input_files]
 
