@@ -6,6 +6,7 @@ import inspect
 import itertools
 import logging
 import os
+
 from logging.handlers import MemoryHandler
 from typing import Any, Optional
 
@@ -17,11 +18,12 @@ class MemoryLogger:
 
     id_iter = itertools.count()
 
-    def __init__(
+    def __init__(  # pylint: disable=too-many-arguments
         self,
         file_name: str,
         lock: Optional[Any],
         log_name: Optional[str] = None,
+        log_level: int = logging.INFO,
         flush_immed: bool = False,
     ) -> None:
         self.instance_id = next(self.id_iter)
@@ -34,17 +36,29 @@ class MemoryLogger:
 
         self._logger = logging.getLogger(log_name)
 
-        self._logger.setLevel(logging.INFO)
+        self._logger.setLevel(log_level)
+
+        fmt = " - ".join(
+            [
+                "[$asctime]",
+                "[$name]",
+                "[$levelname]",
+                "$message",
+            ]
+        )
 
         formatter = logging.Formatter(
-            "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
+            fmt=fmt,
+            style="$",
         )
+
         file_handler = logging.FileHandler(file_name)
         file_handler.setFormatter(formatter)
 
         log_handler = MemoryHandler(
             10000, flushLevel=logging.CRITICAL, target=file_handler
         )
+
         log_handler.setFormatter(formatter)
         self._logger.addHandler(log_handler)
 
@@ -82,46 +96,48 @@ class MemoryLogger:
             if isinstance(handler, MemoryHandler):
                 handler.setTarget(None)
 
-    def log(self, level: int, msg: str) -> None:
+    def log(self, level: int, msg: str, indent_level: int) -> None:
         """
         Wrapper function for logging messages
         """
-        self._logger.log(level, msg)
+        indent_string = " " * 4 * indent_level
+
+        self._logger.log(level, indent_string + msg)
         if self.flush_immed:
             self.flush()
 
-    def debug(self, msg: str) -> None:
+    def debug(self, msg: str, indent_level: int = 0) -> None:
         """
         Wrapper function for debug messages
         """
-        self.log(logging.DEBUG, msg)
+        self.log(logging.DEBUG, msg, indent_level)
 
-    def info(self, msg: str) -> None:
+    def info(self, msg: str, indent_level: int = 0) -> None:
         """
         Wrapper function for info messages
         """
-        self.log(logging.INFO, msg)
+        self.log(logging.INFO, msg, indent_level)
 
-    def warning(self, msg: str) -> None:
+    def warning(self, msg: str, indent_level: int = 0) -> None:
         """
         Wrapper function for warn messages
         """
-        self.log(logging.WARNING, msg)
+        self.log(logging.WARNING, msg, indent_level)
 
-    def error(self, msg: str) -> None:
+    def error(self, msg: str, indent_level: int = 0) -> None:
         """
         Wrapper function for error messages
         """
-        self.log(logging.ERROR, msg)
+        self.log(logging.ERROR, msg, indent_level)
 
-    def fatal(self, msg: str) -> None:
+    def fatal(self, msg: str, indent_level: int = 0) -> None:
         """
         Wrapper function for fatal messages
         """
-        self.log(logging.FATAL, msg)
+        self.log(logging.FATAL, msg, indent_level)
 
-    def critical(self, msg: str) -> None:
+    def critical(self, msg: str, indent_level: int = 0) -> None:
         """
         Wrapper function for critical messages
         """
-        self.log(logging.CRITICAL, msg)
+        self.log(logging.CRITICAL, msg, indent_level)
