@@ -23,60 +23,64 @@ class Result:
     Class to store results of processes
     """
 
-    def __init__(self, status: ResultStatus, message=""):
+    def __init__(self, status: ResultStatus, message: str = ""):
         self.status = status
         self.message = message
 
     def __str__(self):
-        return f"{self.status.name} {self.message}".strip()
+        result_msg = f"{self.status.name}"
+        if self.message != "":
+            result_msg += f", msg: {self.message}"
+
+        return result_msg.rstrip()
 
     @staticmethod
-    def success(message=""):
+    def success(message: str = "") -> "Result":
         """
         Convenience method for generating success messages
         """
         return Result(ResultStatus.SUCCESS, message)
 
     @staticmethod
-    def retry(message=""):
+    def retry(message: str = "") -> "Result":
         """
         Convenience method for generating retry messages
         """
         return Result(ResultStatus.RETRY, message)
 
     @staticmethod
-    def fail(message=""):
+    def fail(message: str = "") -> "Result":
         """
         Convenience method for generating failure messages
         """
         return Result(ResultStatus.FAIL, message)
 
     @staticmethod
-    def skip(message=""):
+    def skip(message: str = "") -> "Result":
         """
         Convenience method for generating skip messages
         """
         return Result(ResultStatus.SKIP, message)
 
-    def is_success(self):
+    def is_success(self) -> bool:
         """
         Convenience method for testing for success messages
         """
         return self.status == ResultStatus.SUCCESS
 
-    def is_retry(self):
+    def is_retry(self) -> bool:
         """
         Convenience method for testing for retry messages
         """
         return self.status == ResultStatus.RETRY
 
-    def is_fail(self):
+    def is_fail(self) -> bool:
         """
         Convenience method for testing for failure messages
         """
         return self.status == ResultStatus.FAIL
 
-    def is_skip(self):
+    def is_skip(self) -> bool:
         """
         Convenience method for testing for skip messages
         """
@@ -105,11 +109,15 @@ class Result:
 
         match response.status_code:
             case response_code if 200 <= response_code <= 299:  # pylint: disable=used-before-assignment
-                return Result.success(f"HTTP Status Code: {response.status_code}")
+                status = ResultStatus.SUCCESS
             case response_code if 500 <= response_code:
                 status = ResultStatus.RETRY
             case _:
                 status = ResultStatus.FAIL
 
-        message = f"HTTP Status Code: {response.status_code}; {response.reason or response.text}"
+        message = f"HTTP Status Code: {response.status_code}"
+
+        if status.name in ["RETRY", "FAIL"]:
+            message = f"{message}; {response.reason or response.text}"
+
         return Result(status, message)
